# Z3Kural - Thirukkural API by Z3Connect

A Python package to fetch Thirukkural verses.

## Installation

pip install z3kural 



## Usage

```python
from z3kural import get_kural

kural = get_kural(1)
print(kural)
